@@ -261,9 +261,9 @@ int scen_add_flags( FILE *dest_file, FILE *scen_file, int id )
     memset( vic_hexes, 0, sizeof(int) * 40 );
     fseek( scen_file, 37, SEEK_SET );
     for ( i = 0; i < 20; i++ ) {
-        fread( &vic_hexes[i * 2], 2, 1, scen_file );
+        _fread( &vic_hexes[i * 2], 2, 1, scen_file );
         vic_hexes[i * 2] = SDL_SwapLE16(vic_hexes[i * 2]);
-        fread( &vic_hexes[i * 2 + 1], 2, 1, scen_file );
+        _fread( &vic_hexes[i * 2 + 1], 2, 1, scen_file );
         vic_hexes[i * 2 + 1] = SDL_SwapLE16(vic_hexes[i * 2 + 1]);
         if ( vic_hexes[i * 2] >= 1000 || vic_hexes[i * 2] < 0 )
             break;
@@ -278,17 +278,17 @@ int scen_add_flags( FILE *dest_file, FILE *scen_file, int id )
     /* read/write map size */
     width = height = 0;
     fseek( map_file, 101, SEEK_SET );
-    fread( &width, 2, 1, map_file ); 
+    _fread( &width, 2, 1, map_file ); 
     width = SDL_SwapLE16(width);
     fseek( map_file, 103, SEEK_SET );
-    fread( &height, 2, 1, map_file ); 
+    _fread( &height, 2, 1, map_file ); 
     height = SDL_SwapLE16(height);
     width++; height++;
     /* owner info */
     fseek( map_file, 123 + 3 * width * height, SEEK_SET );
     for ( y = 0; y < height; y++ ) {
         for ( x = 0; x < width; x++ ) {
-            ibuf = 0; fread( &ibuf, 1, 1, map_file );
+            ibuf = 0; _fread( &ibuf, 1, 1, map_file );
             if ( ibuf > 0 ) {
                 obj = 0;
                 for ( i = 0; i < obj_count; i++ )
@@ -333,8 +333,8 @@ void scen_create_random_weather( FILE *dest_file, FILE *scen_file, int month, in
     memset( weather, 0, sizeof( int ) * turns );
     /* get condition and region */
     fseek( scen_file, 16, SEEK_SET );
-    fread( &init_cond, 1, 1, scen_file );
-    fread( &region, 1, 1, scen_file );
+    _fread( &init_cond, 1, 1, scen_file );
+    _fread( &region, 1, 1, scen_file );
     
     /* compute the weather */
     random_seed( month * turns + ( region + 1 ) * ( init_cond + 1 ) );
@@ -449,25 +449,25 @@ void scen_create_pg_weather( FILE *dest_file, int scen_id, FILE *scen_file, int
 Read unit data from scen_file, convert and write it to dest_file.
 ====================================================================
 */
-void scen_create_unit( int scen_id, FILE *dest_file, FILE *scen_file )
+void scen_create_unit( int scen_id, FILE *dest_file, FILE *scen_file, int is_core_unit )
 {
     int id = 0, nation = 0, x = 0, y = 0, str = 0, entr = 0, exp = 0, trsp_id = 0, org_trsp_id = 0;
     /* read unit -- 14 bytes */
     /* icon id */
-    fread( &id, 2, 1, scen_file ); /* icon id */
+    _fread( &id, 2, 1, scen_file ); /* icon id */
     id = SDL_SwapLE16(id);
-    fread( &org_trsp_id, 2, 1, scen_file ); /* transporter of organic unit */
+    _fread( &org_trsp_id, 2, 1, scen_file ); /* transporter of organic unit */
     org_trsp_id = SDL_SwapLE16(org_trsp_id);
-    fread( &nation, 1, 1, scen_file ); nation--; /* nation + 1 */
-    fread( &trsp_id, 2, 1, scen_file ); /* sea/air transport */
+    _fread( &nation, 1, 1, scen_file ); nation--; /* nation + 1 */
+    _fread( &trsp_id, 2, 1, scen_file ); /* sea/air transport */
     trsp_id = SDL_SwapLE16(trsp_id);
-    fread( &x, 2, 1, scen_file ); /* x */
+    _fread( &x, 2, 1, scen_file ); /* x */
     x = SDL_SwapLE16(x);
-    fread( &y, 2, 1, scen_file ); /* y */
+    _fread( &y, 2, 1, scen_file ); /* y */
     y = SDL_SwapLE16(y);
-    fread( &str, 1, 1, scen_file ); /* strength */
-    fread( &entr, 1, 1, scen_file ); /* entrenchment */
-    fread( &exp, 1, 1, scen_file ); /* experience */
+    _fread( &str, 1, 1, scen_file ); /* strength */
+    _fread( &entr, 1, 1, scen_file ); /* entrenchment */
+    _fread( &exp, 1, 1, scen_file ); /* experience */
     /* FIX: give transporters to artillery in Kiev */
     if (scen_id==23)
     {
@@ -483,7 +483,10 @@ void scen_create_unit( int scen_id, FILE *dest_file, FILE *scen_file )
             unit_entry_used[org_trsp_id - 1] = 1;
     /* write unit */
     fprintf( dest_file, "<unit\n" );
-    fprintf( dest_file, "id%i\nnation%s\n", id - 1, nations[nation * 3] );
+    fprintf( dest_file, "id%i\nnation%s\n", 
+    					 id - 1, nations[nation * 3]);
+	if (is_core_unit)
+		fprintf( dest_file, "core1\n");
     fprintf( dest_file, "x%i\ny%i\n", x, y );
     fprintf( dest_file, "str%i\nentr%i\nexp%i\n", str, entr, exp );
     if ( trsp_id == 0 && org_trsp_id == 0 )
@@ -812,15 +815,16 @@ int write_prestige_info( FILE *file, int turns, int *ppt )
 
 /** Read axis/allies max unit count from file handle @file. 
  * Return -1 on error (values incomplete then) or 0 on success. */
-int read_unit_limit( FILE *file, int *axis_ulimit, int *allies_ulimit )
+int read_unit_limit( FILE *file, int *axis_ulimit, int *axis_core_ulimit, int *allies_ulimit )
 {
 	unsigned char buf[3];
 	
-	*axis_ulimit = *allies_ulimit = 0;
+	*axis_ulimit = *axis_core_ulimit = *allies_ulimit = 0;
 	
 	if (freadat(file, 18, buf, 3) < 3)
 		return -1;
-	*axis_ulimit = buf[0] + buf[1];
+	*axis_ulimit = buf[0] + buf[1]; /* core + aux */
+	*axis_core_ulimit = buf[0];
 	*allies_ulimit = buf[2];
 	return 0;
 }
@@ -890,10 +894,11 @@ int scenarios_convert( int scen_id )
     char path[MAXPATHLEN];
     FILE *dest_file = 0, *scen_file = 0, *aux_file = 0, *scenstat_file = 0;
     PData *pd = 0, *reinf, *unit;
-    int def_str, def_exp, def_entr;
+    int def_str, def_exp;
     char *str;
-    int axis_ulimit = 0, allies_ulimit = 0;
+    int axis_ulimit = 0, axis_core_ulimit = 0, allies_ulimit = 0;
     char scen_title[16], scen_desc[160], scen_author[32];
+	int core_unit_count = 0;
 	
     printf( "Scenarios...\n" );
     
@@ -953,10 +958,10 @@ int scenarios_convert( int scen_id )
         /* read title and description from scenstat file for campaign */
         if ( scen_id == -1 ) {
             fseek( scenstat_file, 40 + (i - 1) * 14, SEEK_SET );
-            fread( dummy, 14, 1, scenstat_file );
+            _fread( dummy, 14, 1, scenstat_file );
             snprintf( scen_title, sizeof(scen_title), "%s", dummy);
             fseek( scenstat_file, 600 + (i - 1) * 160 , SEEK_SET );
-            fread( dummy, 160, 1, scenstat_file );
+            _fread( dummy, 160, 1, scenstat_file );
             snprintf( scen_desc, sizeof(scen_desc), "%s", dummy);
             if (strcmp(target_name,"pg") == 0)
                 snprintf( scen_author, sizeof(scen_author), "SSI" );
@@ -1004,19 +1009,19 @@ int scenarios_convert( int scen_id )
         
         /* date */
         fseek( scen_file, 22, SEEK_SET );
-        day = 0; fread( &day, 1, 1, scen_file );
-        month = 0; fread( &month, 1, 1, scen_file );
-        year = 0; fread( &year, 1, 1, scen_file );
+        day = 0; _fread( &day, 1, 1, scen_file );
+        month = 0; _fread( &month, 1, 1, scen_file );
+        year = 0; _fread( &year, 1, 1, scen_file );
         fprintf( dest_file, "date%02i.%02i.19%i\n", day, month, year );
         
         /* turn limit */
         fseek( scen_file, 21, SEEK_SET );
-        turns = 0; fread( &turns, 1, 1, scen_file );
+        turns = 0; _fread( &turns, 1, 1, scen_file );
         fprintf( dest_file, "turns%i\n", turns );
         fseek( scen_file, 25, SEEK_SET );
-        turns_per_day = 0; fread( &turns_per_day, 1, 1, scen_file );
+        turns_per_day = 0; _fread( &turns_per_day, 1, 1, scen_file );
         fprintf( dest_file, "turns_per_day%i\n", turns_per_day );
-        days_per_turn = 0; fread( &days_per_turn, 1, 1, scen_file );
+        days_per_turn = 0; _fread( &days_per_turn, 1, 1, scen_file );
         if ( turns_per_day == 0 && days_per_turn == 0 )
             days_per_turn = 1;
         fprintf( dest_file, "days_per_turn%i\n", days_per_turn );
@@ -1053,25 +1058,25 @@ int scenarios_convert( int scen_id )
         fprintf( dest_file, ">\n" );
         /* get unit offset */
         fseek( scen_file, 117, SEEK_SET );
-        ibuf = 0; fread( &ibuf, 1, 1, scen_file );
+        ibuf = 0; _fread( &ibuf, 1, 1, scen_file );
         unit_offset = ibuf * 4 + 135;
         /* get prestige data for axis and allies */
         read_prestige_info(scen_file, &pi_axis, &pi_allies );
 	/* get unit limits for axis and allies */
-	read_unit_limit( scen_file, &axis_ulimit, &allies_ulimit );
+	read_unit_limit( scen_file, &axis_ulimit, &axis_core_ulimit, &allies_ulimit );
         /* players */
         fprintf( dest_file, "<players\n" );
         /* axis */
         fseek( scen_file, 12, SEEK_SET );
         /* orientation */
-        axis_orient = 0; fread( &axis_orient, 1, 1, scen_file );
+        axis_orient = 0; _fread( &axis_orient, 1, 1, scen_file );
         if ( axis_orient == 1 ) 
             sprintf( dummy, "right" );
         else
             sprintf( dummy, "left" );
         /* strategy: -2 (very defensive) to 2 (very aggressive) */
         fseek( scen_file, 15, SEEK_SET );
-        axis_strat = 0; fread( &axis_strat, 1, 1, scen_file );
+        axis_strat = 0; _fread( &axis_strat, 1, 1, scen_file );
         if ( axis_strat == 0 ) 
             axis_strat = 1;
         else
@@ -1092,6 +1097,7 @@ int scenarios_convert( int scen_id )
             fprintf( dest_file, "nationsgerausithunbulrumfinesp\n" );
         fprintf( dest_file, "allied_players\n" );
         fprintf( dest_file, "unit_limit%d\n", axis_ulimit );
+        fprintf( dest_file, "core_unit_limit%d\n", axis_core_ulimit );
         fprintf( dest_file, "orientation%s\ncontrolhuman\nstrategy%i\n", dummy, axis_strat );
 	{
 		int ppt[turns]; /* prestige per turn with dynamic size */
@@ -1107,13 +1113,13 @@ int scenarios_convert( int scen_id )
         fprintf( dest_file, "<transporters\n" );
         /* air */
         fseek( scen_file, unit_offset - 8, SEEK_SET );
-        ibuf = 0; fread( &ibuf, 2, 1, scen_file );
+        ibuf = 0; _fread( &ibuf, 2, 1, scen_file );
         ibuf = SDL_SwapLE16(ibuf);
         if ( ibuf )
             fprintf( dest_file, "<air\nunit%i\ncount50\n>\n", ibuf - 1 );
         /* sea */
         fseek( scen_file, unit_offset - 4, SEEK_SET );
-        ibuf = 0; fread( &ibuf, 2, 1, scen_file );
+        ibuf = 0; _fread( &ibuf, 2, 1, scen_file );
         ibuf = SDL_SwapLE16(ibuf);
         if ( ibuf )
             fprintf( dest_file, "<sea\nunit%i\ncount50\n>\n", ibuf - 1 );
@@ -1143,6 +1149,7 @@ int scenarios_convert( int scen_id )
             fprintf( dest_file, "nationsbelluxdenfragreusaturnetnorpolporsosweswiengyug\n" );
         fprintf( dest_file, "allied_players\n" );
         fprintf( dest_file, "unit_limit%d\n", allies_ulimit );
+		fprintf( dest_file, "core_unit_limit0\n" );
         fprintf( dest_file, "orientation%s\ncontrolcpu\nstrategy%i\n", dummy, allied_strat );
 	{
 		int ppt[turns]; /* prestige per turn with dynamic size */
@@ -1158,13 +1165,13 @@ int scenarios_convert( int scen_id )
         fprintf( dest_file, "<transporters\n" );
         /* air */
         fseek( scen_file, unit_offset - 6, SEEK_SET );
-        ibuf = 0; fread( &ibuf, 2, 1, scen_file );
+        ibuf = 0; _fread( &ibuf, 2, 1, scen_file );
         ibuf = SDL_SwapLE16(ibuf);
         if ( ibuf )
             fprintf( dest_file, "<air\nunit%i\ncount50\n>\n", ibuf - 1 );
         /* sea */
         fseek( scen_file, unit_offset - 2, SEEK_SET );
-        ibuf = 0; fread( &ibuf, 2, 1, scen_file );
+        ibuf = 0; _fread( &ibuf, 2, 1, scen_file );
         ibuf = SDL_SwapLE16(ibuf);
         if ( ibuf )
             fprintf( dest_file, "<sea\nunit%i\ncount50\n>\n", ibuf - 1 );
@@ -1194,15 +1201,15 @@ int scenarios_convert( int scen_id )
         }
         /* deployment fields */
         fseek( scen_file, 117, SEEK_SET );
-        ibuf = 0; fread( &ibuf, 2, 1, scen_file );
+        ibuf = 0; _fread( &ibuf, 2, 1, scen_file );
         deploy_fields_count = SDL_SwapLE16(ibuf);
         fprintf( dest_file, "<deployfields\n<player\nidaxis\ncoordinatesdefault" );
         /* last coordinate is always (-1, -1) */
         for (j = 0; j < deploy_fields_count - 1; j++) {
             int x, y;
-            ibuf = 0; fread( &ibuf, 2, 1, scen_file );
+            ibuf = 0; _fread( &ibuf, 2, 1, scen_file );
             x = SDL_SwapLE16(ibuf);
-            ibuf = 0; fread( &ibuf, 2, 1, scen_file );
+            ibuf = 0; _fread( &ibuf, 2, 1, scen_file );
             y = SDL_SwapLE16(ibuf);
             fprintf( dest_file, "%s%d,%d", j ? "" : "", x, y );
         }
@@ -1219,23 +1226,24 @@ int scenarios_convert( int scen_id )
         memset( unit_entry_used, 0, sizeof( unit_entry_used ) );
         /* count them */
         fseek( scen_file, 33, SEEK_SET );
-        ibuf = 0; fread( &ibuf, 1, 1, scen_file );
+        ibuf = 0; _fread( &ibuf, 1, 1, scen_file );
         unit_count = ibuf; /* core */
-        ibuf = 0; fread( &ibuf, 1, 1, scen_file );
+		core_unit_count = unit_count; /* needed for core flag */
+        ibuf = 0; _fread( &ibuf, 1, 1, scen_file );
         unit_count += ibuf; /* allies */
-        ibuf = 0; fread( &ibuf, 1, 1, scen_file );
+        ibuf = 0; _fread( &ibuf, 1, 1, scen_file );
         unit_count += ibuf; /* auxiliary */
         /* build them */
         fseek( scen_file, unit_offset, SEEK_SET );
         fprintf( dest_file, "<units\n" );
         for ( j = 0; j < unit_count; j++ )
-            scen_create_unit( (scen_id!=-1)?(-1):(i-1), dest_file, scen_file );
+            scen_create_unit( (scen_id!=-1)?(-1):(i-1), dest_file, scen_file, j < core_unit_count );
         /* reinforcements -- only for original PG scenarios */
         if ( scen_id == -1 && strcmp(target_name,"pg") == 0 ) {
             if ( parser_get_pdata( pd, fnames[i - 1], &reinf ) ) {
                 /* units come unsorted with the proper nation stored for each
                    unit */
-                def_str = 10; def_exp = 0; def_entr = 0;
+                def_str = 10; def_exp = 0;
                 list_reset( reinf->entries );
                 while ( ( unit = list_next( reinf->entries ) ) )
                     if ( !strcmp( "unit", unit->name ) ) {
