@@ -62,7 +62,7 @@ struct {
 Terrain definitions.
 ====================================================================
 */
-#define NUM_TERRAIN_TYPES 15
+#define NUM_TERRAIN_TYPES 16
 struct {
     char id, *name, *set_name;
     int min_entr, max_entr, max_ini; 
@@ -77,6 +77,10 @@ struct {
         "112211221122",
         { "1111A1X1", "1121A1X1", "1121A1X1" },
         { "none","none","none" } },
+    { 'b', "Bridge", "bridge", 0, 5, 99,
+        "112211221122",
+        { "1111A1X1", "1121A1X1", "1121A1X1" },
+        { "none","none","none" } },
     { '#', "Fields", "fields", 0, 5, 3, 
         "112211221122",
         { "4AA2A1X3", "AAA2A1XA", "AAA2A1X3" },
@@ -141,11 +145,11 @@ int terrain_tile_count = 237;
 char tile_type[] = {
     'o', 'o', 'o', 'o', 'o', 'o', 'o', 'o', 'o', 'o', 'o', 
     'o', 'o', 'o', 'o', 'o', 'o', 'o', 'o', 'o', 'o', 'c',
-    'c', 'o', 'o', 'o', 'h', 'h', 'h', 'h', 'r', 'o', 'r',
-    'c', 'c', 'c', 'c', 'r', 'c', 'c', 'r', 'r', 'o', 'c',
+    'c', 'o', 'o', 'o', 'h', 'h', 'h', 'h', 'b', 'o', 'b',
+    'c', 'c', 'c', 'c', 'r', 'c', 'c', 'b', 'b', 'o', 'c',
     'c', 'c', 'c', 'r', 'r', 'r', 'o', 'o', 'R', 'R', 'R',
-    'R', 'r', 'r', 'r', 'r', 'r', 'R', 'R', 'R', 'R', 'R',
-    'r', 'r', 'r', 'r', 'r', 'R', 'R', 'o', 'r', 'm', 'm',
+    'R', 'r', 'r', 'r', 'r', 'b', 'R', 'R', 'R', 'R', 'R',
+    'r', 'r', 'r', 'r', 'b', 'R', 'R', 'o', 'r', 'm', 'm',
     'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 
     'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 
     'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 
@@ -162,7 +166,7 @@ char tile_type[] = {
     'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm', 'm',
     'm', 'm', 'm', 'm', 'm', 'm',
     /* ??? */
-    'r', 'r', 'r', 'r', 'R', 'R', 'R', 'c', 'h', 'h', 'd',
+    'b', 'b', 'b', 'b', 'R', 'R', 'R', 'c', 'h', 'h', 'd',
     'd', 'd', 'd'
 };
 
@@ -186,7 +190,6 @@ static int terrain_convert_tiles( char id, PG_Shp *shp, char *fname )
     SDL_Surface *surf;
     char path[MAXPATHLEN];
     int count = 0;
-    SDL_Surface *fixed_road;
     int is_road = !strcmp( fname, "road" );
     
     /* count occurence */
@@ -215,22 +218,19 @@ static int terrain_convert_tiles( char id, PG_Shp *shp, char *fname )
     pos = 0; count = 0;
     for ( i = 0; i < terrain_tile_count; i++ )
         if ( tile_type[i] == id ) {
-            /* the third road tile is buggy so we need to copy the fixed one */
-            if ( is_road && count == 2 ) {
-                snprintf( path, MAXPATHLEN, "%s/convdata/road2.bmp", get_gamedir() );
-                if ( ( fixed_road = SDL_LoadBMP( path ) ) == 0 ) {
-                    fprintf( stderr, "%s: %s\n", path, SDL_GetError() );
-                    return 0;
-                }
-                srect.y = 0; drect.x = pos;
-                SDL_BlitSurface( fixed_road, &srect, surf, &drect );
-            }
-            else {
+			/* road tile no 0 is buggy ... */
+			if (!is_road || count != 0) {
                 srect.y = i * 50;
                 drect.x = pos;
                 SDL_BlitSurface( shp->surf, &srect, surf, &drect );
-            }
-            pos += 60;
+			}
+			/* ... but can be repaired by mirroring tile no 3 */
+			if (is_road && count == 3) {
+				srect.y = i * 50;
+                drect.x = 0 * 60;
+				copy_surf_mirrored(shp->surf, &srect, surf, &drect);
+			}
+			pos += 60;
             count++;
         }
 
@@ -429,6 +429,7 @@ int terrain_convert_graphics( void )
     if ( ( shp = shp_load( "TACMAP.SHP" ) ) == 0 ) goto failure;
     if ( !terrain_convert_tiles( 'c', shp, "clear" ) ) goto failure;
     if ( !terrain_convert_tiles( 'r', shp, "road" ) ) goto failure;
+    if ( !terrain_convert_tiles( 'b', shp, "bridge" ) ) goto failure;
     if ( !terrain_convert_tiles( '#', shp, "fields" ) ) goto failure;
     if ( !terrain_convert_tiles( '~', shp, "rough" ) ) goto failure;
     if ( !terrain_convert_tiles( 'R', shp, "river" ) ) goto failure;
