@@ -158,6 +158,7 @@ int map_load( char *fname )
             map[x][y].nation = 0;
             map[x][y].player = 0;
             map[x][y].deploy_center = 0;
+            map[x][y].damaged = 0;
             /* default is no mil target */
             map[x][y].obj = 0;
             /* check tile type */
@@ -934,7 +935,7 @@ void map_draw_terrain( SDL_Surface *surf, int map_x, int map_y, int x, int y )
         SOURCE( tile->terrain->images[cur_weather], tile->image_offset, 0 )
     blit_surf();
     /* nation flag */
-    if ( tile->nation != 0 ) {
+    if ( tile->nation !=0 && tile->damaged == 0) {
         nation_draw_flag( tile->nation, surf,
                           x + ( ( hex_w - nation_flag_width ) >> 1 ),
                           y + hex_h - nation_flag_height - 2,
@@ -1631,34 +1632,14 @@ static MapCoord *map_create_new_coord(int x, int y)
 }
 static void map_add_default_deploy_fields( Player *player, List *fields )
 {
-    int i,j,x,y,next_x,next_y,okay;
+    int x, y;
     Unit *unit;
-    list_reset(units);
-    while ((unit=list_next(units)))
-    {
-        if (unit->player == player && unit_supports_deploy(unit))
-        {
-            for (i=0;i<6;i++)
-                if (get_close_hex_pos(unit->x,unit->y,i,&next_x,&next_y))
-                {
-                    okay = 1;
-                    for (j=0;j<6;j++)
-                        if (get_close_hex_pos(next_x,next_y,j,&x,&y))
-                            if (!mask[x][y].spot||
-                                (map[x][y].a_unit&&!player_is_ally(player,map[x][y].a_unit->player))||
-                                (map[x][y].g_unit&&!player_is_ally(player,map[x][y].g_unit->player)))
-                            {
-                                okay = 0; break;
-                            }
-                    if (map[next_x][next_y].terrain->flags[cur_weather]&RIVER) okay = 0;
-                    mask[next_x][next_y].deploy = okay;
-                }
-        }
-    }
+
     list_reset(units);
     while ((unit=list_next(units))) /* make sure all units can be re-deployed */
         if (unit->player == player && unit_supports_deploy(unit))
             mask[unit->x][unit->y].deploy = 1;
+
     map_add_deploy_centers_to_deploy_mask(player,0);
     for ( x = 0; x < map_w; x++ )
         for ( y = 0; y < map_h; y++ )
@@ -1669,8 +1650,8 @@ static void map_add_default_deploy_fields( Player *player, List *fields )
 /*
 ====================================================================
 Set deploy mask by player's field list. If first entry is (-1,-1),
-create a default mask, using the initial layout of spotting and 
-units.
+create a default mask by adding all tiles with own unit on (but 
+not the surrounding to prevent moving front line one step ahead).
 ====================================================================
 */
 static void map_set_initial_deploy_mask( Player *player )
@@ -1686,7 +1667,7 @@ static void map_set_initial_deploy_mask( Player *player )
     list_reset( field_list );
     while ( ( pt = list_next( field_list ) ) ) {
         Mask_Tile *tile = map_mask_tile(pt->x, pt->y);
-        if (!tile) 
+        if (!tile) /* -1,-1 */
         {
             list_delete_current(field_list);
             map_add_default_deploy_fields(player,field_list);
@@ -1786,7 +1767,7 @@ int map_get_unit_supply_level( int mx, int my, Unit *unit )
         supply_level = 0;
         for ( i = x; i < x + w; i++ )
             for ( j = y; j < y + h; j++ )
-                if ( map[i][j].player && player_is_ally( unit->player, map[i][j].player ) ) {
+                if ( map_is_allied_depot(&map[i][j], unit) ) {
                     flag_supply_level = get_dist( mx, my, i, j );
                     if ( flag_supply_level < 2 ) flag_supply_level = 100;
                     else {
@@ -1842,6 +1823,8 @@ int map_is_allied_depot( Map_Tile *tile, Unit *unit )
             if ( !(tile->terrain->flags[cur_weather] & SUPPLY_SHIPS) )
                 return 0;
         }
+	if (tile->damaged) // currently damaged by carpet bombing
+		return 0;
     return 1;
 }
 /*
