@@ -22,6 +22,7 @@
 #include "unit.h"
 #include "file.h"
 #include "map.h"
+#include "campaign.h"
 #include "scenario.h"
 #include "localize.h"
 
@@ -56,12 +57,19 @@ extern Font *log_font;
 extern Setup setup;
 extern int deploy_turn;
 extern List *unit_lib;
+extern Camp_Entry *camp_cur_scen;
+extern int camp_loaded;
 
 /*
 ====================================================================
 Scenario data.
 ====================================================================
 */
+
+List *prev_scen_core_units = 0;	//list of units transfered between scenarios
+				//type: transferredUnitProp in unit.h
+char *prev_scen_fname = 0;	//file name of previous scenario
+
 Setup setup;            /* engine setup with scenario information */
 Scen_Info *scen_info = 0;
 int *weather = 0;       /* weather type for each turn as id to weather_types */
@@ -191,6 +199,31 @@ static void update_nations_purchase_flag()
 			nations[i].no_purchase = 1;
 }
 
+/** Check if core unit transfer is possible. */
+static int core_transfer_allowed()
+{
+	if (!camp_loaded)
+		return 0; /* transferring is only for campaign */
+	if (!prev_scen_core_units)
+		return 0; /* no core units saved from last scenario */
+	if (prev_scen_core_units->count == 0)
+		return 0; /* no units in list */
+	if (strcmp(camp_cur_scen->core_transfer,"denied") == 0)
+		return 0; /* core transfer is always denied */
+	if (strcmp(camp_cur_scen->core_transfer,"allowed") == 0)
+		return 1; /* core transfer is always allowed */
+
+	/* core transfer is okay if scenario (file name) matches
+	 * the from clause, e.g., from:pg/Poland */
+	if (strncmp(camp_cur_scen->core_transfer,"from:",5))
+		return 0; /* doesn't start with from: */
+	if (prev_scen_fname == 0)
+		return 0; /* previous scenario file name missing */
+	if (strcmp(camp_cur_scen->core_transfer+5, prev_scen_fname) == 0)
+		return 1; /* previous scenario matches */
+	return 0;
+}
+
 /*
 ====================================================================
 Publics
@@ -316,6 +349,8 @@ int scen_load( const char *fname )
 	
 	/* unit limit (0 = no limit) */
 	parser_get_int(sub, "unit_limit", &player->unit_limit);
+	/* core units + aux units = unit_limit */
+	parser_get_int(sub, "core_unit_limit", &player->core_unit_limit);
 	
         if ( !parser_get_value( sub, "orientation", &str, 0 ) ) goto parser_failure;
         if ( STRCMP( str, "right" ) ) /* alldirs not implemented yet */
@@ -555,6 +590,10 @@ int scen_load( const char *fname )
     reinf = list_create( LIST_AUTO_DELETE, unit_delete );
     avail_units = list_create( LIST_AUTO_DELETE, unit_delete );
     vis_units = list_create( LIST_NO_AUTO_DELETE, LIST_NO_CALLBACK );
+
+	if ( core_transfer_allowed() )
+		unit_ref += scen_load_core_units(); /* transfer old units */
+
     if ( !parser_get_entries( pd, "units", &entries ) ) goto parser_failure;
     list_reset( entries );
     while ( ( sub = list_next( entries ) ) ) {
@@ -575,8 +614,16 @@ int scen_load( const char *fname )
             fprintf( stderr, tr("%s: no player controls this nation\n"), unit_base.nation->name );
             goto failure;
         }
-        /* name */
-        unit_set_generic_name( &unit_base, unit_ref + 1, unit_prop->name );
+	/* core flag (if not set/found: auxiliary unit) */
+	if (camp_loaded)
+		parser_get_int( sub, "core", &unit_base.core );
+	else
+		unit_base.core = 0; /* no core stuff in single scenario */
+       /* name */
+       if ( !parser_get_value( sub, "name", &str,0) )
+           unit_set_generic_name( &unit_base, unit_ref + 1, unit_prop->name );
+       else
+           strcpy_lt( unit_base.name, str, 31 );
         /* delay */
         unit_delayed = parser_get_int( sub, "delay", &unit_base.delay );
         /* position */
@@ -586,7 +633,7 @@ int scen_load( const char *fname )
             fprintf( stderr, tr("%s: out of map: ignored\n"), unit_base.name );
             continue;  
         }
-        /* strengt, entrenchment, experience */
+        /* strength, entrenchment, experience */
         if ( !parser_get_int( sub, "str", &unit_base.str ) ) goto parser_failure;
         if ( !parser_get_int( sub, "entr", &unit_base.entr ) ) goto parser_failure;
         if ( !parser_get_int( sub, "exp", &unit_base.exp_level ) ) goto parser_failure;
@@ -615,25 +662,28 @@ int scen_load( const char *fname )
         }
         /* actual unit */
         unit = unit_create( unit_prop, trsp_prop, &unit_base );
-        /* put unit to active or reinforcements list */
-        if ( !unit_delayed ) {
-            list_add( units, unit );
-            /* add unit to map */
-            map_insert_unit( unit );
-        }
-        else if (!config.purchase) /* no fixed reinfs with purchase enabled */
-            list_add( reinf, unit );
-        /* adjust transporter count */
-        if ( unit->embark == EMBARK_SEA ) {
-            unit->player->sea_trsp_count++;
-            unit->player->sea_trsp_used++;
-        }
-        else
-            if ( unit->embark == EMBARK_AIR ) {
-                unit->player->air_trsp_count++;
-                unit->player->air_trsp_used++;
-            }
-        unit_ref++;
+        /* put unit to active or reinforcements list */		//not so fast
+	if ( unit->core != 1 || ( !core_transfer_allowed() ) )
+	{				//if unit is core, and we have
+	    if ( !unit_delayed ) {	//to transfer forces, we shouldn't
+		list_add( units, unit );//put them. Exception: unit->core=2
+		/* add unit to map */
+		map_insert_unit( unit );
+	    }
+	    else if (!config.purchase) /* no fixed reinfs with purchase enabled */
+		list_add( reinf, unit );
+	    /* adjust transporter count */
+	    if ( unit->embark == EMBARK_SEA ) {
+	         unit->player->sea_trsp_count++;
+	         unit->player->sea_trsp_used++;
+	    }
+	    else
+	    if ( unit->embark == EMBARK_AIR ) {
+		unit->player->air_trsp_count++;
+		unit->player->air_trsp_used++;
+	    }
+	    unit_ref++;
+	}
     }
     /* load deployment hexes */
     if ( parser_get_entries( pd, "deployfields", &entries ) ) {
@@ -923,7 +973,8 @@ int scen_check_result( int after_last_turn )
     if (f) {
         unsigned len;
         scen_result[0] = '\0';
-        fgets(scen_result, sizeof scen_result, f);
+        if (!fgets(scen_result, sizeof scen_result, f))
+		/* do nothing as scen_result is simply empty then */;
         fclose(f);
         len = strlen(scen_result);
         if (len > 0 && scen_result[len-1] == '\n') scen_result[len-1] = '\0';
@@ -1088,3 +1139,155 @@ int scen_inc_casualties_for_unit( Unit *unit )
         cnt = scen_inc_casualties( player, unit->trsp_prop.class );
     return cnt;
 }
+
+/*
+====================================================================
+Add core units to list that will be used in next scenario.
+Return unit quantity.
+====================================================================
+*/
+int scen_save_core_units( )
+{
+    int n_units = 0;		//how many units we saved?
+    Unit * current;
+    transferredUnitProp * cur;	//local copy of unit parameters
+
+	/* save file name for restricted core transfers */
+#ifdef DEBUG_CORETRANSFER
+	printf("saving core units for %s\n", scen_info->fname);
+#endif
+	if (prev_scen_fname)
+		free(prev_scen_fname);
+	prev_scen_fname = strdup(scen_info->fname);
+
+    if ( !prev_scen_core_units && units )
+	prev_scen_core_units = list_create( LIST_AUTO_DELETE, LIST_NO_CALLBACK );
+    else if (prev_scen_core_units) 
+	list_clear(prev_scen_core_units);
+
+    if ( units )
+	if ( !list_empty( units ) )
+	{
+	    current = list_first( units );
+	    do
+		//don't transfer killed units
+		if ( current->core && !current->killed )
+		{
+		    cur = unit_create_transfer_props( current );
+		    list_add( prev_scen_core_units, cur);
+		    n_units++;
+		}
+	    while( (current = list_next( units )) );
+	}
+    if ( reinf )
+	if ( !list_empty( reinf ) )
+	{
+	    current = list_first( reinf );
+	    do
+		if ( current->core )
+		{
+		    cur = unit_create_transfer_props( current );
+		    list_add( prev_scen_core_units, cur);
+		    n_units++;
+		}
+	    while( (current = list_next( reinf )) );
+	}
+    if ( avail_units )
+	if ( !list_empty( avail_units ) )
+	{
+	    current = list_first( avail_units );
+	    do
+		if ( current->core )
+		{
+		    cur = unit_create_transfer_props( current );
+		    list_add( prev_scen_core_units, cur);
+		    n_units++;
+		}
+	    while( (current = list_next( avail_units )) );
+	}
+#ifdef DEBUG_CORETRANSFER
+	printf("saved %d core units\n", n_units);
+#endif
+    return n_units;
+}
+/*
+====================================================================
+Load core units from list. Return unit quantity.
+====================================================================
+*/
+int scen_load_core_units()
+{
+    int n_units = 0;
+    transferredUnitProp * current;
+    Unit_Lib_Entry *unit_prop=0, *trsp_prop = 0;
+    Unit unit_base;
+    Unit * unit;
+
+    if ( prev_scen_core_units && !list_empty( prev_scen_core_units ) )
+    {
+	list_reset( prev_scen_core_units );
+	current = list_first( prev_scen_core_units );
+	do
+	{
+		/* fix all pointers and icon settings in properties */
+		unit_prop = unit_lib_find( current->prop_id );
+		current->prop.id = unit_prop->id;
+		current->prop.name = unit_prop->name;
+		current->prop.icon = unit_prop->icon;
+		current->prop.icon_tiny = unit_prop->icon_tiny;
+		current->prop.icon_type = unit_prop->icon_type;
+		current->prop.icon_w = unit_prop->icon_w;
+		current->prop.icon_h = unit_prop->icon_h;
+		current->prop.icon_tiny_w = unit_prop->icon_tiny_w;
+		current->prop.icon_tiny_h = unit_prop->icon_tiny_h;
+#ifdef WITH_SOUND
+		current->prop.wav_alloc = unit_prop->wav_alloc;
+		current->prop.wav_move = unit_prop->wav_move;
+#endif
+		trsp_prop = unit_lib_find( current->trsp_prop_id );
+		if (trsp_prop) {
+			current->trsp_prop.id = trsp_prop->id;
+			current->trsp_prop.name = trsp_prop->name;
+			current->trsp_prop.icon = trsp_prop->icon;
+			current->trsp_prop.icon_tiny = trsp_prop->icon_tiny;
+			current->trsp_prop.icon_type = trsp_prop->icon_type;
+			current->trsp_prop.icon_w = trsp_prop->icon_w;
+			current->trsp_prop.icon_h = trsp_prop->icon_h;
+			current->trsp_prop.icon_tiny_w = trsp_prop->icon_tiny_w;
+			current->trsp_prop.icon_tiny_h = trsp_prop->icon_tiny_h;
+#ifdef WITH_SOUND
+			current->trsp_prop.wav_alloc = trsp_prop->wav_alloc;
+			current->trsp_prop.wav_move = trsp_prop->wav_move;
+#endif
+		}
+
+		/* create unit base */
+		memset( &unit_base, 0, sizeof( Unit ) );
+		strcpy_lt( unit_base.name, current->name, 20 );
+		unit_base.core = 1;
+		unit_base.player = player_get_by_id( current->player_id );
+		unit_base.nation = nation_find( current->nation_id );
+		unit_base.str = current->str;
+		unit_base.orient = unit_base.player->orient;
+		strcpy_lt( unit_base.tag, current->tag, 31 );
+		
+		/* create unit */
+		unit_prop = &current->prop;
+		if (trsp_prop)
+			trsp_prop = &current->trsp_prop;
+		unit = unit_create( unit_prop, trsp_prop, &unit_base );
+		
+		/* set experience */
+		unit_add_exp(unit, current->exp);
+		
+		/* add to reinforcements */
+		list_add( reinf, unit );
+		n_units++;
+	}
+	while ( (current = list_next( prev_scen_core_units )) );
+    }
+#ifdef DEBUG_CORETRANSFER
+	printf("loaded %d core units\n", n_units);
+#endif
+    return n_units;
+}
