@@ -57,6 +57,8 @@ extern int camp_loaded;
 extern char *camp_fname;
 extern Camp_Entry *camp_cur_scen;
 extern Map_Tile **map;
+extern List *prev_scen_core_units;
+extern char *prev_scen_fname;
 
 /*
 ====================================================================
@@ -88,6 +90,9 @@ enum StorageVersion {
     StoreUnitIsGuarding,	/* up to this versions are stored per unit */
     StoreGlobalVersioning,
     StorePurchaseData, /* cost for unit lib entries, prestige for players */
+	StoreCoreUnitFlag, /* units have now core/aux flag */
+	StoreTileDamage, /* deploy center and damaged info */
+	StoreCoreTransferList, /* previous' scenarios core units for campaigns */
     /* insert new versions before this comment */
     StoreMaxVersion,
     StoreHighestSupportedVersion = StoreMaxVersion - 1,
@@ -120,7 +125,7 @@ Save/load slot name to/from file.
 */
 static void slot_read_name( Slot *slot, FILE *file )
 {
-    fread( slot->name, sizeof( slot->name ), 1, file );
+    _fread( slot->name, sizeof( slot->name ), 1, file );
 }
 static void slot_write_name( Slot *slot, FILE *file )
 {
@@ -203,9 +208,9 @@ static char* load_string( FILE *file )
     char *str = 0;
     int length;
 
-    fread( &length, sizeof( int ), 1, file );
+    _fread( &length, sizeof( int ), 1, file );
     str = calloc( length + 1, sizeof( char ) );
-    fread( str, sizeof( char ), length, file );
+    _fread( str, sizeof( char ), length, file );
     str[length] = 0;
     return str;
 }
@@ -228,7 +233,7 @@ enum UnitStoreParams {
             ,
     UnitNameSize = 21*sizeof(char) + 3*sizeof(char)/*padding*/,
     UnitTagSize = 32*sizeof(char),
-    UnitSize = 2*UnitLibSize + 5*sizeof(void *) + UnitNameSize + UnitTagSize + 26*sizeof(int),
+    UnitSize = 2*UnitLibSize + 5*sizeof(void *) + UnitNameSize + UnitTagSize + 27*sizeof(int),
 };
 static void save_unit_lib_entry( FILE *file, Unit_Lib_Entry *entry )
 {
@@ -348,7 +353,7 @@ static void save_unit( FILE *file, Unit *unit )
     save_int(file, unit->exp);
     /* unit storage version (was: exp_level) */
     COMPILE_TIME_ASSERT_SYMBOL(unit->exp_level);
-    save_int(file, StoreUnitIsGuarding);
+    save_int(file, StoreCoreUnitFlag);
     /* delay */
     save_int(file, unit->delay);
     /* embark */
@@ -376,8 +381,9 @@ static void save_unit( FILE *file, Unit *unit )
     /* is_guarding (was: damage_bar_offset) */
     COMPILE_TIME_ASSERT_SYMBOL(unit->damage_bar_offset);
     save_int(file, unit->is_guarding);
-    /* reserved (was: suppr) */
-    save_int(file, unit->suppr);
+    /* core unit flag (was: suppr) */
+	COMPILE_TIME_ASSERT_SYMBOL(unit->suppr);
+    save_int(file, unit->core);
     /* turn_suppr */
     save_int(file, unit->turn_suppr);
     /* killed */
@@ -405,12 +411,11 @@ static void save_unit( FILE *file, Unit *unit )
 static void load_unit_lib_entry( FILE *file, Unit_Lib_Entry *entry )
 {
     int i;
-    void *p;
     /* write each member */
     /* reserved */
-    p = load_pointer(file);
+    load_pointer(file);
     /* reserved (was: name) */
-    p = load_pointer(file);
+    load_pointer(file);
     /* nation (since StorePurchaseData) */
     entry->nation = -1;
     if (store_version >= StorePurchaseData)
@@ -504,7 +509,7 @@ Unit* load_unit( FILE *file )
     /* reserved */
     load_pointer(file);
     /* name */
-    fread(unit->name, UnitNameSize, 1, file);
+    _fread(unit->name, UnitNameSize, 1, file);
     unit->name[UnitNameSize - 1] = 0;
     /* reserved */
     load_pointer(file);
@@ -551,8 +556,12 @@ Unit* load_unit( FILE *file )
     /* is_guarding (was: damage_bar_offset) */
     val = load_int(file);
     unit->is_guarding = unit_store_version >= StoreUnitIsGuarding ? val : 0;
-    /* reserved (was: suppr) */
-    load_int(file);
+    /* core unit flag (was: suppr) */
+    val = load_int(file);
+	if (unit_store_version >= StoreCoreUnitFlag)
+		unit->core = val;
+	else
+		unit->core = 0;
     /* turn_suppr */
     unit->turn_suppr = load_int(file);
     /* killed */
@@ -560,7 +569,7 @@ Unit* load_unit( FILE *file )
     /* reserved (was: fresh_deploy) */
     load_int(file);
     /* tag */
-    fread(unit->tag, UnitTagSize, 1, file);
+    _fread(unit->tag, UnitTagSize, 1, file);
     unit->tag[UnitTagSize - 1] = 0;
     /* reserved (was: eval_score) */
     load_int(file);
@@ -684,7 +693,7 @@ static void load_map_tile_units( FILE *file, Unit **unit, Unit **air_unit )
 }
 /*
 ====================================================================
-Save map flags: nation id and player id strings
+Save map flags: nation id and player id strings, damage, deploy center
 ====================================================================
 */
 static void save_map_tile_flag( FILE *file, Map_Tile *tile )
@@ -697,8 +706,13 @@ static void save_map_tile_flag( FILE *file, Map_Tile *tile )
         save_string( file, tile->player->id );
     else
         save_string( file, "none" );
+	
+	/* deploy level and damage */
+	save_int(file, tile->deploy_center);
+	save_int(file, tile->damaged);
 }
-static void load_map_tile_flag( FILE *file, Nation **nation, Player **player )
+static void load_map_tile_flag( FILE *file, Nation **nation, Player **player,
+					int *deploy_center, int *damaged)
 {
     char *str;
     str = load_string( file );
@@ -707,6 +721,100 @@ static void load_map_tile_flag( FILE *file, Nation **nation, Player **player )
     str = load_string( file );
     *player = player_get_by_id( str );
     free( str );
+    
+	/* deploy level and damage */
+	if (store_version >= StoreTileDamage) {
+		*deploy_center = load_int(file);
+		*damaged = load_int(file);
+	}
+}
+
+/* Load/save core unit transfer list */
+static void save_prev_scen_core_units( FILE *file )
+{
+	int num = 0;
+	transferredUnitProp *prop;
+	
+	/* save number of entries */
+	if (prev_scen_core_units)
+		num = prev_scen_core_units->count;
+	save_int(file, num);
+	if (num == 0)
+		return; /* no more data */
+
+	/* save scenario file name */
+	save_string(file, prev_scen_fname);
+
+	/* save entries */
+	list_reset(prev_scen_core_units);
+	while ((prop = list_next(prev_scen_core_units))) {
+		save_unit_lib_entry(file, &prop->prop);
+		save_unit_lib_entry(file, &prop->trsp_prop);
+		save_string(file, prop->prop_id);
+		save_string(file, prop->trsp_prop_id);
+		save_string(file, prop->name);
+		save_string(file, prop->player_id);
+		save_string(file, prop->nation_id);
+		save_int(file, prop->str);
+		save_int(file, prop->exp);
+		save_string(file, prop->tag);
+	}
+}
+static void load_prev_scen_core_units( FILE *file )
+{
+	int i, num;
+	transferredUnitProp *prop;
+	char *str;
+	
+	/* load number */
+	num = load_int(file);
+	if (num == 0) {
+		if (prev_scen_core_units)
+			list_clear(prev_scen_core_units);
+		return; /* nothing follows */
+	}
+	
+	/* create list if not yet existing */
+	if (!prev_scen_core_units)
+		prev_scen_core_units = list_create( LIST_AUTO_DELETE, LIST_NO_CALLBACK );
+	else
+		list_clear(prev_scen_core_units);
+
+	/* read scenario file name */
+	if (prev_scen_fname)
+		free(prev_scen_fname);
+	prev_scen_fname = load_string(file);
+
+	/* create and push entries to list */
+	for (i = 0; i < num; i++) {
+		prop = calloc( 1, sizeof( transferredUnitProp ) );
+		
+		load_unit_lib_entry(file, &prop->prop);
+		load_unit_lib_entry(file, &prop->trsp_prop);
+		
+		str = load_string(file);
+		snprintf( prop->prop_id, sizeof(prop->prop_id), "%s",str);
+		free(str);
+		str = load_string(file);
+		snprintf( prop->trsp_prop_id, sizeof(prop->trsp_prop_id), "%s",str);
+		free(str);
+		str = load_string(file);
+		snprintf( prop->name, sizeof(prop->name), "%s",str);
+		free(str);
+		str = load_string(file);
+		snprintf( prop->player_id, sizeof(prop->player_id), "%s",str);
+		free(str);
+		str = load_string(file);
+		snprintf( prop->nation_id, sizeof(prop->nation_id), "%s",str);
+		free(str);
+		prop->str = load_int(file);
+		prop->exp = load_int(file);
+		str = load_string(file);
+		snprintf( prop->tag, sizeof(prop->tag), "%s",str);
+		free(str);
+		
+		list_add(prev_scen_core_units, prop);
+	}
 }
 
 /*
@@ -729,7 +837,7 @@ void slots_init()
     FILE *file = 0;
     /* set all slots empty */
     for ( i = 0; i < SLOT_COUNT; i++ ) {
-        sprintf( slots[i].name, "<emtpy>" );
+        sprintf( slots[i].name, "<empty>" );
         slots[i].fname[0] = 0;
         slots[i].valid = 0;
     }
@@ -798,6 +906,7 @@ int slot_save( int id, char *name )
         campaign loaded
         campaign name (optional)
         campaign scenario id (optional)
+        core transfer list (optional)
         scenario file name
         fog_of_war
         supply
@@ -816,7 +925,7 @@ int slot_save( int id, char *name )
         map width
         map height
         map tile units
-        map tile flags
+        map tile flags + deploy/damage info
     */
     /* if we ever hit this, we have *big* problems */
     COMPILE_TIME_ASSERT(StoreHighestSupportedVersion <= StoreVersionLimit);
@@ -838,6 +947,7 @@ int slot_save( int id, char *name )
     if ( camp_loaded ) {
         save_string( file, camp_fname );
         save_string( file, camp_cur_scen->id );
+        save_prev_scen_core_units( file );
     }
     /* basic data */
     save_string( file, scen_info->fname );
@@ -905,7 +1015,7 @@ int slot_load( int id )
     /* read slot identification -- won't change anything but the file handle needs to move */
     slot_read_name( &slots[id], file );
     /* read version */
-    fread( &store_version, sizeof( int ), 1, file );
+    _fread( &store_version, sizeof( int ), 1, file );
     /* check for endianness */
     endian_need_swap = !!(store_version & 0xFFFF0000);
     if (endian_need_swap)
@@ -932,6 +1042,11 @@ int slot_load( int id )
         str = load_string( file );
         camp_set_cur( str );
         free( str );
+        
+	if (store_version >= StoreCoreTransferList)
+		load_prev_scen_core_units( file );
+	else if (prev_scen_core_units)
+		list_clear(prev_scen_core_units);
     }
     /* the scenario that is loaded now is the one that belongs to the scenario id of the campaign above */
     /* read scenario file name */
@@ -998,7 +1113,8 @@ int slot_load( int id )
         }
     for ( i = 0; i < map_w; i++ )
         for ( j = 0; j < map_h; j++ )
-            load_map_tile_flag( file, &map[i][j].nation, &map[i][j].player );
+            load_map_tile_flag( file, &map[i][j].nation, &map[i][j].player,
+				&map[i][j].deploy_center, &map[i][j].damaged);
     /* cannot have deployment-turn (those cannot be saved) */
     deploy_turn = 0;
     fclose( file );
